@@ -1,11 +1,14 @@
-from typing import Optional
-from pydantic import BaseModel
+from typing import List, Optional
+from pydantic import BaseModel, Field
 from .base import PerPageRequest
 
 class AttributeFilter(PerPageRequest):
-    name: Optional[str] = None
-    type: Optional[str] = None
-    group: Optional[str] = None
+    name: Optional[str] = Field(None, alias="filter[name]")
+    type: Optional[List[str]] = Field(None, alias="filter[type][]")
+    group: Optional[List[str]] = Field(None, alias="filter[group][]")
+    
+    class Config:
+        allow_population_by_field_name = True
 
 
 class AttributeListItem(BaseModel):
